// NEJDULEZITEJSI parametr - pocet svetel
lights = 6;

module prism(l, w, h){
       polyhedron(
               points=[[0,0,0], [l,0,0], [l,w,0], [0,w,0], [0,w,h], [l,w,h]],
               faces=[[0,1,2,3],[5,4,3,2],[0,4,5,1],[0,3,4],[5,2,1]]
               );
}

module prism2(height, width_min, width_max, thickness) {
    diff = (width_max - width_min) / 2;
    linear_extrude(height = thickness)
    polygon(
        points = [
            [0, 0], [width_max, 0], 
            [diff + width_min, height], [diff, height]
        ]
    );
}

/**
- sirka 5mm
- vyska 9.2 (2 svetla), 15.2 (4 svetla) -> 3.2mm + 3mm / svetlo
- sirka hlavniho tela 2.4mm
- vyska 11.6mm
- cedulka sirka 2.4mm
- otvor na svetla 1.5mm

- od stredu horniho otvoru k horni hrane: 1.5mm
- od stredu dolniho otvoru k dolni hrane indikatoru: 2mm
*/

width = 5;
// sirka stredu navestidla, kde jsou lampy
body_width = 2.4;
// vyska zkoseni v dolni a horni casti
prism_height = 0.8;
// tloustka hlavy navestidla
thickness = 1;
// sirka dolni casti s tabulkous
indicator_width = body_width;
// vyska dolni casti s tabulkou
indicator_height = 1;

// Pevna vyska hlavy navestidla, pak se pridava po 
// krocich light_height podle poctu svetel
fixed_height = 3.2;
light_height = 3;

// toustja naznaceneho deleni hlavy navestidla
bar_width = 0.15;

body_height = fixed_height - 2 * prism_height + lights * light_height;

module base(lights) {
    rotate([0, 0, 90])
    prism2(prism_height, body_width, width, thickness);

    body_height = fixed_height - 2 * prism_height + lights * light_height;

    cube([body_height, width, thickness]);

    translate([body_height, width, 0])
    rotate([0, 0, -90])
    prism2(prism_height, body_width, width, thickness);

    // pricne spoje
    translate([0.6, 0, thickness])
    cube([bar_width, width , 0.2]);

    for (i = [1 : lights]) {
        translate([0.6 + light_height * i, 0, thickness])
        cube([0.2, width , 0.2]);
    }

    // podelne spoje
    translate([0.6, 1, thickness])
    cube([body_height - 2*0.6 - 0.2, bar_width , 0.2]);

    translate([0.6, width - 1 - 0.2, thickness])
    cube([body_height - 2*0.6 - 0.2, bar_width , 0.2]);
}

module holes(n) {
    translate([0, 0, -1])
    union() {
        for (i = [1 : n]) {
            translate([0.2 + 1.5 + 0.5 + (i - 1) * light_height, width / 2, thickness])
            cylinder(d = 1.6, h=2, $fn=100);
        }
    }
}

difference() {
    base(lights);
    holes(lights);
}

// stinitka
for (i = [0 : lights - 1]) {
    translate([0.4 + 1.5 + 0.3 + i * light_height, width / 2, thickness])
    translate([0, 0, 4])
    rotate([180, 0, 0])
    difference() {
        cylinder (h=4, d=2.5, $fn=100);
        cylinder (h=6, d=2, $fn=100);

        rotate(a=7, v=[0,1,0])
        translate ([0,-1.5,0])
            cube([2,3,3]);
        translate ([0.8,-1.5,2])
            cube([2,3,1.6]);
    }
}

// deska s indikatory
translate([body_height + prism_height, (width - body_width) / 2, 0])
cube([indicator_height, indicator_width, thickness]);

// Vnitrni svetla sirka 3.2
// Tloustka bocnice 0.7
translate([0, 3.1 / 2, 0])
translate([1.3, width / 2, -1.5])
cube([lights * light_height - light_height / 2 + 0.2, 0.5, 1.5]);

translate([0, -3.1 / 2, 0])
translate([1.3, width / 2, -1.5])
translate([0, -0.5, 0])
cube([lights * light_height - light_height / 2 + 0.2, 0.5, 1.5]);
